@@ -134,11 +134,11 @@ def excel_writer(df:pd.DataFrame, output_file:Path, sheet_name):
 
 def df_col_search(df:pd.DataFrame, srch_string: str):
     '''
-    Searches given string in column header in lower case
+    Searches given string in column header in lower case and returns list of columns where string is found.
+    Case insensitive.
     '''
     col_list = []
     for col in df.columns:
         if srch_string in col.lower():
-            print(col)
             col_list.append(col)
     return col_list
